@@ -28,7 +28,8 @@ def xnat_build_dataset(xnat_configuration, minimal=True):
     with xnat.connect(server=xnat_configuration['server'],
                       user=xnat_configuration['user'],
                       password=xnat_configuration['password'],
-                      verify=bool(os.getenv('MLOPS_SSL'))) as session:
+                      verify=xnat_configuration['verify'],
+                      ) as session:
 
         logger.info(f"Collecting XNAT project: {xnat_configuration['project']}")
         project = session.projects[xnat_configuration["project"]]
