@@ -8,7 +8,7 @@ import glob
 from monai.transforms import MapTransform, LoadImage
 from monai.config import KeysCollection
 from mlops.utils.logger import logger
-
+import time
 
 class LoadImageXNATd(MapTransform):
     """
@@ -38,23 +38,27 @@ class LoadImageXNATd(MapTransform):
                     with xnat.connect(server=self.xnat_configuration['server'],
                                       user=self.xnat_configuration['user'],
                                       password=self.xnat_configuration['password'],
-                                      verify=bool(os.getenv('MLOPS_SSL'))) as session:
+                                      verify=self.xnat_configuration['verify'],
+                                      ) as session:
 
-                        "connect session to subject uri"
+                        # "connect session to subject uri"
                         subject_obj = session.create_object(d['subject_uri'])
-                        "perform action on subject object"
+                        logger.debug(f"Found XNAT subject: {subject_obj}")
+
+                        # "perform action on subject object"
                         try:
                             xnat_obj = action(subject_obj)
+                            logger.debug(f"Running {action} found XNAT obj: {xnat_obj}")
                         except TypeError:
                             logger.warn(f'No suitable data found for action {action} and subject {d["subject_uri"]}')
-                            d[data_label] = None
+                            xnat_obj = None
 
                         if self.validate_data:
-                            if xnat_obj:
+                            if xnat_obj is not None:
                                 d[data_label] = True
                             else:
                                 d[data_label] = False
-                            return d
+                                return d
 
                         with tempfile.TemporaryDirectory() as tmpdirname:
                             "download image from XNAT"
